Type

Enum Type 

pub enum Type {
    Reference(TypeRef),
    Tuple(TypeTuple),
    PathWithGenerics(PathWithGenerics),
    Path(TypePath),
}

Variants



Reference(TypeRef)



Tuple(TypeTuple)



PathWithGenerics(PathWithGenerics)



Path(TypePath)

Implementations

Source

impl Type

pub fn as_result(&self) -> Option<(&Type, &Type)>

Extract Ok and Err types if this is Result<T, E>

pub fn has_lifetime(&self) -> bool

Check if type contains a lifetime anywhere in the tree

pub fn has_named_lifetime(&self, name: &str) -> bool

Check if type contains the named lifetime anywhere in the tree.

pub fn has_non_named_lifetime(&self, name: &str) -> bool

Check if type contains any named lifetime other than name.

pub fn has_elided_reference_lifetime(&self) -> bool

Check if type contains any &T reference without an explicit lifetime.

We require explicit 'roam for borrowed RPC return payloads.

pub fn contains_channel(&self) -> bool

Check if type contains Tx or Rx at any nesting level

Note: This is a heuristic based on type names. Proper validation should happen at codegen time when we can resolve types properly.