pub trait ToTokens {
// Required method
fn to_tokens(&self, tokens: &mut TokenStream);
// Provided methods
fn to_token_iter(&self) -> TokenIter { ... }
fn into_token_iter(self) -> TokenIter
where Self: Sized { ... }
fn to_token_stream(&self) -> TokenStream { ... }
fn into_token_stream(self) -> TokenStream
where Self: Sized { ... }
fn tokens_to_string(&self) -> String { ... }
}Expand description
unsynn defines its own ToTokens trait to be able to implement it for std container types.
This is similar to the ToTokens from the quote crate but adds some extra methods and is
implemented for more types. Moreover the to_token_iter() method is the main entry point
for crating an iterator that can be used for parsing.
Using with the unsynn! macro
The [unsynn!] macro provides convenient syntax sugar for customizing token emission via the
to_tokens clause. See the macro documentation
for details.
unsynn! {
struct BoolKeyword(bool);
to_tokens |s, tokens| {
let keyword = if s.0 { "true" } else { "false" };
Ident::new(keyword, Span::call_site()).to_tokens(tokens);
};
}Required Methods
Sourcefn to_tokens(&self, tokens: &mut TokenStream)
fn to_tokens(&self, tokens: &mut TokenStream)
Write &self to the given TokenStream.
This is the core method that needs to be implemented. All other methods in this trait have default implementations based on this method.
Using with the unsynn! macro
The [unsynn!] macro’s to_tokens clause provides syntax sugar for implementing this
method. See unsynn! documentation.
Provided Methods
Sourcefn to_token_iter(&self) -> TokenIter
fn to_token_iter(&self) -> TokenIter
Convert &self into a TokenIter object.
Sourcefn into_token_iter(self) -> TokenIterwhere
Self: Sized,
fn into_token_iter(self) -> TokenIterwhere
Self: Sized,
Convert self into a TokenIter object.
Sourcefn to_token_stream(&self) -> TokenStream
fn to_token_stream(&self) -> TokenStream
Convert &self into a TokenStream object.
Sourcefn into_token_stream(self) -> TokenStreamwhere
Self: Sized,
fn into_token_stream(self) -> TokenStreamwhere
Self: Sized,
Convert self into a TokenStream object.
Sourcefn tokens_to_string(&self) -> String
fn tokens_to_string(&self) -> String